powered by
Internal environment to track which default warnings have been shown in the current session to avoid duplicate warnings.
.fastml_warned_defaults
An object of class environment of length 0.
environment