powered by
Prints a formatted summary of all available tuning complexity presets with their characteristics and recommended use cases.
print_tuning_presets()
Invisibly returns a data frame with preset information.